require("car")
require("phia")
require("lme4")

## EXPERIMENT 1

# Data - non-native speakers' data are not included (data already collated by IVT)
exp1<-read.table("dataNPnormal.txt",header=T)

# Digits 4-6 indicate the target PAIR, digit 2 is different for the 2 partners
exp1$item<-paste(substr(exp1$code,2,2),substr(exp1$code,4,6))
# Digit 3 indicates the prime type
exp1$primetype<-ifelse(substr(exp1$code,3,3)==5,"identity",
                  ifelse(substr(exp1$code,3,3)==6,"neighbourly","control"))
# Digit 1 indicates the lexicality
exp1$lex<-ifelse(substr(exp1$code,1,1)=="1","word","nonword")

# These are our standard cutoffs for item accuracy, trial RT
itemacc1<-with(exp1,aggregate(acc=="cor",list(item=item),mean))
baditems1<-with(itemacc1,item[x<.6])
exp1<-subset(exp1,acc=="cor"&rt>150&rt<1500&!(item%in%baditems1)&lex=="word"
                  &!(subject%in%c(30,44,149,150)))
# Remove participants: 30 & 44 for accuracy; 149 & 150 for counterbalancing reasons

# Full model - singular fit
m1F<-lmer(rt~primetype+(primetype|subject)+(primetype|item),exp1,
  control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))

m1Ff<-lmer(rt~primetype+(as.factor(primetype)|subject)+(as.factor(primetype)|item),exp1,
          control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))


#  model without random correlations - singular fit
m1NC<-lmer(rt~primetype+(primetype||subject)+(primetype||item),exp1,
          control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))

# Drop subject slope to achieve convergence
m1<-lmer(rt~primetype+(1|subject)+(primetype|item),exp1,
         control=lmerControl(optimizer="bobyqa",optCtrl=list()))

# more detailed investigation of singularity
m1NCalt<-lmer(rt~primetype+(1|subject)+(1|item)+
              (0+I(1*(primetype=="identity"))|subject)+(0+I(1*(primetype=="identity"))|item)+
              (0+I(1*(primetype=="neighbourly"))|subject)+(0+I(1*(primetype=="neighbourly"))|item),
              exp1,
          control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))

m1NCalt_2<-lmer(rt~primetype+(1|subject)+(1|item)+
                (0+I(1*(primetype=="identity"))|subject)+(0+I(1*(primetype=="identity"))|item)+
                (0+I(1*(primetype=="neighbourly"))|item),
              exp1,
              control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))

m1alt_2<-lmer(rt~primetype+(I(primetype=="identity")|subject)+(primetype|item),
                exp1,
                control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))

# conclusion: no subject variability in control-neighbourly contrast

anova(m1F,m1) # extra parameters for random slopes not significant change
anova(m1NC,m1) # not reported but ditto

# mean RTs
with(exp1,aggregate(rt,list(primetype=primetype),mean))

# non-converged model - Omnibus ANOVA
Anova(m1F)  
# only the control-neighbourly contrast is of interest, but it's simpler to use adjustment="none" than to create the contrast manually
testInteractions(m1F,adjustment="none")

# reported model
Anova(m1) 
testInteractions(m1,adjustment="none")

# also converges, not reported
Anova(m1NCalt_2)
testInteractions(m1NCalt_2)

# also converges, not reported
Anova(m1alt_2)
testInteractions(m1alt_2)


## EXPERIMENT 2

# Data - non-native speakers' data are not included (data already collated by IVT)
exp2<-read.table("dataNPaddMask.txt",header=T)

# Data coded as above
exp2$item<-paste(substr(exp2$code,2,2),substr(exp2$code,4,6))
exp2$primetype<-ifelse(substr(exp2$code,3,3)==5,"identity",
                  ifelse(substr(exp2$code,3,3)==6,"neighbourly","control"))
exp2$lex<-ifelse(substr(exp2$code,1,1)=="1","word","nonword")

# Our standard exclusions
itemacc2<-with(exp2,aggregate(acc=="cor",list(item=item),mean))
baditems2<-with(itemacc2,item[x<.6])
exp2<-subset(exp2,acc=="cor"&rt>150&rt<1500&!(item%in%baditems2)&lex=="word")

# Full random slopes - singular
m2F<-lmer(rt~primetype+(primetype|subject)+(primetype|item),exp2,
         control=lmerControl(optimizer="bobyqa",optCtrl=list()))

# Drop random correlations - singular
m2NC<-lmer(rt~primetype+(primetype||subject)+(primetype||item),exp2,
          control=lmerControl(optimizer="bobyqa",optCtrl=list()))

# Try dropping only subject slopes - singular
m2S<-lmer(rt~primetype+(1|subject)+(primetype||item),exp2,
           control=lmerControl(optimizer="bobyqa",optCtrl=list()))

# Try dropping only item slopes - singular
m2I<-lmer(rt~primetype+(primetype||subject)+(1|item),exp2,
          control=lmerControl(optimizer="bobyqa",optCtrl=list()))

# Drop both random slopes to achieve convergence - 
m2<-lmer(rt~primetype+(1|subject)+(1|item),exp2,
         control=lmerControl(optimizer="bobyqa",optCtrl=list()))

# more detailed investigation of singularity
m2NCalt<-lmer(rt~primetype+(1|subject)+(1|item)+
                (0+I(1*(primetype=="identity"))|subject)+(0+I(1*(primetype=="identity"))|item)+
                (0+I(1*(primetype=="neighbourly"))|subject)+(0+I(1*(primetype=="neighbourly"))|item),
              exp2,
              control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))

m2NCalt_2<-lmer(rt~primetype+(1|subject)+(1|item)+
                (0+I(1*(primetype=="identity"))|subject)+(0+I(1*(primetype=="identity"))|item)+
                (0+I(1*(primetype=="neighbourly"))|item),
              exp2,
              control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))

m2alt_2<-lmer(rt~primetype+(I(primetype=="identity")|subject)+(primetype|item),
              exp2,
              control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))

m2alt_2a<-lmer(rt~primetype+(I(primetype=="identity")|subject)+(1|item)+(0+I(1*(primetype=="identity"))|item)+
                 (0+I(1*(primetype=="neighbourly"))|item),
              exp2,
              control=lmerControl(optimizer="bobyqa",optCtrl=list(maxfun=2e5)))

# conclusion: no subject variability in control-neighbourly contrast
#             also some issue relating to random correlation on item

anova(m2F,m2) # extra parameters for random slopes not significant change

# Mean RTs
with(exp2,aggregate(rt,list(primetype=primetype),mean))

# reported model - Anova for Omnibus test
Anova(m2)
# only the control-neighbourly contrast is of interest, but it's simpler to use adjustment="none" than to create a single contrast manually
testInteractions(m2,adjustment="none")

# non-converged model
Anova(m2F)
testInteractions(m2F,adjustment="none")

# also converges, not reported
Anova(m2NCalt_2)
testInteractions(m2NCalt_2,adjustment="none")

# also converges, not reported
Anova(m2alt_2a)
testInteractions(m2alt_2a,adjustment="none")
